@@ -144,9 +144,11 @@ def is_stdlib_name(modname):
     if module is None:
         return False
 
-    # six installs crap with no __file__
-    modpath = os.path.abspath(getattr(module, '__file__', ''))
-    return is_stdlib_path(modpath)
+    origin = getattr(module, '__file__', None)
+    if origin is None:
+        return False
+
+    return is_stdlib_path(os.path.abspath(origin))
 
 
 _STDLIB_PATHS = _stdlib_paths()
@@ -1300,26 +1302,17 @@ class ResourceResponder(object):
             content = importlib.resources.read_binary(fullname, resource)
         except (FileNotFoundError, IsADirectoryError):
             content = None
+
+        msg = mitogen.core.Message.pickled(
+            (fullname, resource), content,
+            dst_id=stream.protocol.remote_id,
+            handle=mitogen.core.LOAD_RESOURCE,
+        )
+
         if content is not None:
-            self._send_resource(stream, fullname, resource, content)
+            self._router._async_route(msg)
         else:
-            self._send_not_found(stream, fullname, resource)
-
-    def _send_resource(self, stream, fullname, resource, content):
-        msg = mitogen.core.Message.pickled(
-            (fullname, resource, content),
-            dst_id=stream.protocol.remote_id,
-            handle=mitogen.core.LOAD_RESOURCE,
-        )
-        self._router._async_route(msg)
-
-    def _send_not_found(self, stream, fullname, resource):
-        msg = mitogen.core.Message.pickled(
-            (fullname, resource, None),
-            dst_id=stream.protocol.remote_id,
-            handle=mitogen.core.LOAD_RESOURCE,
-        )
-        stream.protocol.send(msg)
+            stream.protocol.send(msg)
 
 
 class Broker(mitogen.core.Broker):
