@@ -12,6 +12,7 @@ import mitogen.master
 import testlib
 
 from mitogen.core import b
+from mitogen.core import next
 
 
 class ConstructorTest(testlib.TestCase):
@@ -317,6 +318,30 @@ class PickledTest(testlib.TestCase):
         )
 
 
+class UnpickleIterTest(testlib.TestCase):
+    def roundtrip(self, *args, **kwargs):
+        msg1 = mitogen.core.Message.pickled(*args, **kwargs)
+        return msg1.unpickle_iter()
+
+    def test_ints(self):
+        self.assertEqual(list(self.roundtrip(1, 2, 3)), [1, 2, 3])
+
+    def test_mixed(self):
+        msg = mitogen.core.Message.pickled((u'foo.bar', u'baz.txt'), b('abc'))
+        self.assertFalse(b('_codecs') in msg.data)
+        self.assertFalse(b('encode') in msg.data)
+        self.assertFalse(b('latin1') in msg.data)
+
+        parts = msg.unpickle_iter()
+        self.assertEqual(next(parts), (u'foo.bar', u'baz.txt'))
+        self.assertEqual(next(parts), b('abc'))
+        self.assertRaises(StopIteration, next, parts)
+
+    def test_default_find_class_denies(self):
+        msg = mitogen.core.Message.pickled(1j)
+        self.assertRaises(mitogen.core.UnpicklingError, next, msg.unpickle_iter())
+
+
 class ReplyTest(testlib.TestCase):
     # getting_started.html#rpc-serialization-rules
     klass = mitogen.core.Message
